@@ -26,6 +26,9 @@ def initialize(apiInstance, appInstance) :
     apiInstance.schedulerManager.start()
     log.success(initialize, f'APScheduler schedulers initialized{"" if apiInstance.schedulerManager.api_enabled else ". But are disabled"}')
 
+def onHttpRequestClose(apiInstance, appInstance):
+    ...
+
 def onShutdown(apiInstance, appInstance) :
     @appInstance.teardown_appcontext
     def closeAPSchedulerSchedulers(error):
