@@ -318,6 +318,9 @@ def addResource(apiInstance, appInstance):
 def initialize(apiInstance, appInstance) :
     log.success(initialize, 'SessionManager is running')
 
+def onHttpRequestClose(apiInstance, appInstance):
+    ...
+
 def onShutdown(apiInstance, appInstance) :
     @appInstance.teardown_appcontext
     def closeSessionManager(error):
